const express = require('express');
const router = express.Router();
const axios = require('axios');
const mammoth = require('mammoth');
const { auth } = require('../middlewares/auth');

/**
 * 依据传递过来的 docx 文件的 url ，将 docx 的内容转换为 string 返回
 * 1. 下载 docx 文件
 * 2. 将 docx 文件转换为 string
 * 3. 返回 string
 * 
 * * 使用 `axios` 库来下载 docx 文件 @https://www.npmjs.com/package/axios
 * * 使用 `mammoth` 库来将 docx 文件转换为 string @https://www.npmjs.com/package/mammoth
 */

router.post('/docx2text', auth, async (req, res) => {
  try {
    const { url } = req.body;
    
    if (!url) {
      return res.status(400).json({ error: 'URL is required' });
    }

    // 下载 docx 文件
    const response = await axios({
      method: 'get',
      url: url,
      responseType: 'arraybuffer'
    });

    console.info('extractRawText url: ', url);
    // 使用 mammoth 转换文档内容
    const result = await mammoth.extractRawText({ buffer: response.data });
    
    // 返回转换后的文本
    res.json({ text: result.value });
  } catch (error) {
    console.error('Error processing docx file:', error);
    res.status(500).json({ error: 'Failed to process docx file' });
  }
});

module.exports = router;
